@@ -8,7 +8,6 @@ from typing import List, Optional, Mapping, IO
 
 import click
 from cached_property import cached_property
-from la_panic.panic_parser.bug_type import BugType as KernelPanicBugType
 from la_panic.panic_parser.kernel_panic import KernelPanic
 
 Frame = namedtuple('Frame', 'image_name image_base image_offset symbol symbol_offset')
@@ -16,12 +15,168 @@ Register = namedtuple('Register', 'name value')
 
 
 class BugType(Enum):
+    WatchdogTimeout = '28'
+    BasebandStats = '195'
+    GPUEvent = '284'
+    Sandbox = '187'
+    TerminatingStackshot = '509'
+    ServiceWatchdogTimeout = '29'
+    Session = '179'
+    LegacyStackshot = '188'
+    MACorrelation = '197'
+    iMessages = '189'
+    log_power = '278'
+    PowerLog = 'powerlog'
+    DuetKnowledgeCollector2 = '58'
+    BridgeRestore = '83'
+    LegacyJetsam = '198'
+    ExcResource_385 = '385'
+    Modem = '199'
+    Stackshot = '288'
+    SystemInformation = 'system_profile'
+    Jetsam_298 = '298'
+    MemoryResource = '30'
+    Bridge = '31'
+    DifferentialPrivacy = 'diff_privacy'
+    FirmwareIntegrity = '32'
+    CoreAnalytics_33 = '33'
+    AutoBugCapture = '34'
+    EfiFirmwareIntegrity = '35'
+    SystemStats = '36'
+    AnonSystemStats = '37'
+    Crash_9 = '9'
+    Jetsam_98 = '98'
+    LDCM = '100'
+    Panic_10 = '10'
+    Spin = '11'
+    CLTM = '101'
+    Hang = '12'
+    Panic_110 = '110'
+    ConnectionFailure = '13'
+    MessageTracer = '14'
+    LowBattery = '120'
+    Siri = '201'
+    ShutdownStall = '17'
+    Panic_210 = '210'
+    SymptomsCPUUsage = '202'
+    AssumptionViolation = '18'
+    CoreHandwriting = 'chw'
+    IOMicroStackShot = '44'
+    CoreAnalytics_211 = '211'
+    SiriAppPrediction = '203'
+    spin_45 = '45'
+    PowerMicroStackshots = '220'
+    BTMetadata = '212'
+    SystemMemoryReset = '301'
+    ResetCount = '115'
+    AutoBugCapture_204 = '204'
+    WifiCrashBinary = '221'
+    MicroRunloopHang = '310'
+    Rosetta = '213'
+    glitchyspin = '302'
+    System = '116'
+    IOPowerSources = '141'
+    PanicStats = '205'
+    PowerLog_230 = '230'
+    LongRunloopHang = '222'
+    HomeProductsAnalytics = '311'
+    DifferentialPrivacy_150 = '150'
+    Rhodes = '214'
+    ProactiveEventTrackerTransparency = '303'
+    WiFi = '117'
+    SymptomsCPUWakes = '142'
+    SymptomsCPUUsageFatal = '206'
     Crash_109 = '109'
+    ShortRunloopHang = '223'
+    CoreHandwriting_231 = '231'
+    ForceReset = '151'
+    SiriAppSelection = '215'
+    PrivateFederatedLearning = '304'
+    Bluetooth = '118'
+    SCPMotion = '143'
+    HangSpin = '207'
+    StepCount = '160'
+    RTCTransparency = '224'
+    DiagnosticRequest = '312'
+    MemorySnapshot = '152'
+    Rosetta_B = '216'
+    AudioAccessory = '305'
+    General = '119'
+    HotSpotIOMicroSS = '144'
+    GeoServicesTransparency = '233'
+    MotionState = '161'
+    AppStoreTransparency = '225'
+    SiriSearchFeedback = '313'
+    BearTrapReserved = '153'
+    Portrait = '217'
+    AWDMetricLog = 'metriclog'
+    SymptomsIO = '145'
+    SubmissionReserved = '170'
+    WifiCrash = '209'
+    Natalies = '162'
+    SecurityTransparency = '226'
+    BiomeMapReduce = '234'
+    MemoryGraph = '154'
+    MultichannelAudio = '218'
+    honeybee_payload = '146'
+    MesaReserved = '171'
+    WifiSensing = '235'
+    SiriMiss = '163'
+    ExcResourceThreads_227 = '227'
+    TestA = 'T01'
+    NetworkUsage = '155'
+    WifiReserved = '180'
+    SiriActionPrediction = '219'
+    honeybee_heartbeat = '147'
+    ECCEvent = '172'
+    KeyTransparency = '236'
+    SubDiagHeartBeat = '164'
+    ThirdPartyHang = '228'
+    OSFault = '308'
+    CoreTime = '156'
+    WifiDriverReserved = '181'
     Crash_309 = '309'
-    ExcResourceThreads = '327'
-    ExcResource = '385'
-    ForceReset = KernelPanicBugType.FORCE_RESET.value
-    Panic = KernelPanicBugType.FULL.value
+    honeybee_issue = '148'
+    CellularPerfReserved = '173'
+    TestB = 'T02'
+    StorageStatus = '165'
+    SiriNotificationTransparency = '229'
+    TestC = 'T03'
+    CPUMicroSS = '157'
+    AccessoryUpdate = '182'
+    xprotect = '20'
+    MultitouchFirmware = '149'
+    MicroStackshot = '174'
+    AppLaunchDiagnostics = '238'
+    KeyboardAccuracy = '166'
+    GPURestart = '21'
+    FaceTime = '191'
+    DuetKnowledgeCollector = '158'
+    OTASUpdate = '183'
+    ExcResourceThreads_327 = '327'
+    ExcResource_22 = '22'
+    DuetDB = '175'
+    ThirdPartyHangDeveloper = '328'
+    PrivacySettings = '167'
+    GasGauge = '192'
+    MicroStackShots = '23'
+    BasebandCrash = '159'
+    GPURestart_184 = '184'
+    SystemWatchdogCrash = '409'
+    FlashStatus = '176'
+    SleepWakeFailure = '24'
+    CarouselEvent = '168'
+    AggregateD = '193'
+    WakeupsMonitorViolation = '25'
+    DifferentialPrivacy_50 = '50'
+    ExcResource_185 = '185'
+    UIAutomation = '177'
+    ping = '26'
+    SiriTransaction = '169'
+    SURestore = '194'
+    KtraceStackshot = '186'
+    WirelessDiagnostics = '27'
+    PowerLogLite = '178'
 
 
 class CrashReportBase:
@@ -266,11 +421,11 @@ def get_crash_report_from_file(crash_report_file: IO) -> CrashReportBase:
 
     bug_type_parsers = {
         BugType.ForceReset: KernelModeCrashReport,
-        BugType.Panic: KernelModeCrashReport,
+        BugType.Panic_210: KernelModeCrashReport,
         BugType.Crash_109: UserModeCrashReport,
         BugType.Crash_309: UserModeCrashReport,
-        BugType.ExcResourceThreads: UserModeCrashReport,
-        BugType.ExcResource: UserModeCrashReport,
+        BugType.ExcResourceThreads_327: UserModeCrashReport,
+        BugType.ExcResource_385: UserModeCrashReport,
     }
 
     parser = bug_type_parsers.get(bug_type)
